@@ -40,7 +40,7 @@ G_BEGIN_DECLS
  * application compile time, rather than from the library linked
  * against at application run time.
  */
-#define GTK_SOURCE_MINOR_VERSION (12)
+#define GTK_SOURCE_MINOR_VERSION (14)
 
 /**
  * GTK_SOURCE_MICRO_VERSION:
@@ -49,7 +49,7 @@ G_BEGIN_DECLS
  * application compile time, rather than from the library linked
  * against at application run time.
  */
-#define GTK_SOURCE_MICRO_VERSION (1)
+#define GTK_SOURCE_MICRO_VERSION (2)
 
 
 /**
@@ -147,6 +147,16 @@ G_BEGIN_DECLS
  */
 #define GTK_SOURCE_VERSION_5_12 (G_ENCODE_VERSION (5, 12))
 
+/**
+ * GTK_SOURCE_VERSION_5_14:
+ *
+ * A macro that evaluates to the 5.14 version of GtkSourceView,
+ * in a format that can be used by the C pre-processor.
+ *
+ * Since: 5.14
+ */
+#define GTK_SOURCE_VERSION_5_14 (G_ENCODE_VERSION (5, 14))
+
 /* Define GTK_SOURCE_VERSION_CUR_STABLE */
 #ifndef __GTK_DOC_IGNORE__
 #  if (GTK_SOURCE_MINOR_VERSION % 2)
@@ -260,6 +270,12 @@ G_BEGIN_DECLS
 # define GTK_SOURCE_AVAILABLE_IN_5_12 _GTK_SOURCE_EXTERN
 #endif
 
+#if GTK_SOURCE_VERSION_MAX_ALLOWED < GTK_SOURCE_VERSION_5_14
+# define GTK_SOURCE_AVAILABLE_IN_5_14 G_UNAVAILABLE(5, 14) _GTK_SOURCE_EXTERN
+#else
+# define GTK_SOURCE_AVAILABLE_IN_5_14 _GTK_SOURCE_EXTERN
+#endif
+
 #endif /* __GTK_DOC_IGNORE__ */
 
 GTK_SOURCE_AVAILABLE_IN_ALL
